summaryrefslogtreecommitdiff
path: root/packages/hostap/build.sh
diff options
context:
space:
mode:
Diffstat (limited to 'packages/hostap/build.sh')
-rwxr-xr-xpackages/hostap/build.sh11
1 files changed, 7 insertions, 4 deletions
diff --git a/packages/hostap/build.sh b/packages/hostap/build.sh
index c66bda3d..c356672a 100755
--- a/packages/hostap/build.sh
+++ b/packages/hostap/build.sh
@@ -16,15 +16,18 @@ fi
echo "I: Copy Debian build instructions"
cp -a ${SRC_DEB}/debian ${SRC}
-# Preserve Debian's default of allowing TLSv1.0 for compatibility
-find ${SRC}/debian/patches -mindepth 1 ! -name allow-tlsv1.patch -delete
-echo 'allow-tlsv1.patch' > ${SRC}/debian/patches/series
+# Preserve Debian's default of allowing TLSv1.0 and legacy renegotiation for
+# compatibility with networks that use legacy crypto
+cat > ${SRC}/debian/patches/series << EOF
+allow-tlsv1.patch
+allow-legacy-renegotiation.patch
+EOF
# Build Debian package
cd ${SRC}
echo "I: Ensure Debian build dependencies are met"
-sudo mk-build-deps --install --tool "apt-get --yes --no-install-recommends"
+sudo mk-build-deps --install --tool "apt-get --yes --no-install-recommends" -Ppkg.wpa.nogui,noudeb
echo "I: Create new Debian Package version"
version="$(git describe --tags | tr _ .)"